Plot Predicted Probability Density Function (PDF) for a Single Observation
Source:R/SPQRX.R
eval.plot.pdf.RdGenerates a plot of the predicted probability density function (PDF) for a single observation
using a fitted SPQRX model. The x-axis is the response variable y, and the y-axis
represents the predicted density. The plot is restricted to the range between the 1st and 99th
predicted quantiles for better visualization.
Arguments
- model
A fitted SPQRX model object returned by
fit_spqrx().- x0
A numeric vector representing the covariate values for the observation to plot.
- npdf_points
Integer. Number of points to evaluate the PDF along the y-axis. Default is 500.